# UTF-8 encoded Italian translation file for use with Oddmuse
#
# Copyright (c) 2005 Flavio Poletti
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: italian-utf8.pl,v 1.9 2006/08/18 22:46:10 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Lettura non consentita: l'utente, l'IP o la rete risultano bloccati.
%s calls

Could not create %s
Impossibile creare %s
Invalid UserName %s: not saved.
Lo UserName %s non è valido: nessun salvataggio.
UserName must be 50 characters or less: not saved
Lo UserName deve avere al massimo 50 caratteri: nessun salvataggio
This page contains an uploaded file:
Questa pagina contiene un file:
Recursive include of %s!

Clear Cache

Main lock obtained.
Blocco principale (main) ottenuto.
Main lock released.
Blocco principale (main) rilasciato.
Comments on this page
Commenti su questa pagina
XML::RSS is not available on this system.
Il modulo Perl XML:RSS non è disponibile su questo sistema.
diff

history
cronologia
%s returned no data, or LWP::UserAgent is not available.
Nessun dato da %s, o LWP::UserAgent non è disponibile.
RSS parsing failed for %s
Parsing RSS fallito per %s
No items found in %s.
Nessun elemento trovato in %s.
 . . . . 

Click to edit this page
Cliccare per modificare questa pagina
image
immagine
download

CGI Internal error: %s

Invalid action parameter %s
Parametro d'azione %s non valido
Invalid URL.
URL non valida
Page name is missing
Manca il nome della pagina
Page name is too long: %s
Nome di pagina troppo lungo: %s
Invalid Page %s (must not end with .db)
Pagina %s non valida (non può terminare in .db)
Invalid Page %s (must not end with .lck)
Pagina %s non valida (non può terminare in .lck)
Invalid Page %s
Pagina %s non valida
Preview:
Anteprima:
Preview only, not yet saved
Solo anteprima, ancora nessun salvataggio
Please go on to %s.
Per favore procedere a %s.
No updates since %s
Nessuna modifica da %s
Updates since %s
Modifiche da %s
Updates in the last %s days
Modifiche negli ultimi %s giorni 
Updates in the last %s day
Modifiche nell'ultimo %s giorno
for %s only
solo per %s
List latest change per page only
Elenca solo le ultime modifiche per pagina
List all changes
Elenca tutte le modifiche
Skip rollbacks

Include rollbacks

List only major changes
Elenca solo le modifiche maggiori
Include minor changes
Includi le modifiche minori
%s days
%s giorni
List later changes
Elenca i cambiamenti successivi
Filters
Filtri
Title:

Title and Body:

Username:
Nome utente
Host:

Language:
Lingua:
Go!
Vai!
(minor)
(minore)
rollback

new
nuovo
from %s
da %s
This page is too big to send over RSS.

History of %s
Cronologia di %s
Compare
Confronta
Deleted

Mark this page for deletion

No other revisions available

current

Revision %s
Revisione %s
Contributors to %s

Missing target for rollback.
Obiettivo per il rollback mancante.
Target for rollback is too far back.
L'obiettivo per il rollback è troppo indietro.
Rolling back changes
Annullando le modifiche
The two revisions are the same.

Editing not allowed for %s.
Modifiche non consentite per %s.
Rollback to %s
Rollback a %s
%s rolled back

to %s

Index of all pages
Indice di tutte le pagine
Wiki Version
Versione Wiki
Unlock Wiki
Sblocca la Wiki
Password

Run maintenance
Lancia la routine di mantenimento
Unlock site
Sblocca il sito
Lock site
Blocca il sito
Install CSS

Unlock %s
Sblocca %s
Lock %s
Blocca %s
Administration
Amministrazione
Actions:
Azioni:
Important pages:
Pagine importanti
To mark a page for deletion, put <strong>%s</strong> on the first line.
Per impostare una pagine per la cancellazione, inserire <strong>%s</strong> sulla prima riga.
[Home]

redirected from %s
rediretto da %s
Click to search for references to this page
Clicca per cercare riferimenti a questa pagina
Cookie: 

Warning
Attenzione
Database is stored in temporary directory %s
Il database è collocato nella directory temporanea %s
%s seconds
%s secondi
The same page on other sites:
La stessa pagina su altri siti:
EditNearLinks

Last edited
Modificata l'ultima volta
Edited
Modificata
by %s
da %s
(diff)

Edit revision %s of this page
Modifica la revisione %s di questa pagina
Edit this page
Modifica questa pagina
e

This page is read-only
Questa pagina è in sola lettura
View other revisions
Guarda altre revisioni
View current revision
Guarda la revisione corrente
View all changes
Guarda tutti i cambiamenti
View contributors

Homepage URL:

s

Save
Salva
p

Preview
Anteprima
Search:
Cerca:
f

Replace:
Rimpiazza:
Validate HTML
Convalida HTML
Validate CSS
Convalida CSS
Last edit

Difference between revision %1 and %2
Differenza (dalla revisione %1 alla %2)
revision %s
revisione %s
current revision
revisione corrente
Last major edit (%s)

later minor edits

No diff available.
Nessun diff disponibile.
Old revision:
Vecchia revisione:
Changed:
Cambiato:
Deleted:

Added:
Aggiunto:
to
a
Revision %s not available
la revisione %s non è disponibile
showing current revision instead
mostrata invece la revisione corrente
Showing revision %s
Sto mostrando la revisione %s
Cannot save a nameless page.
Impossibile salvare una pagina senza nome.
Cannot save a page without revision.
Impossibile salvare una pagina senza revisione.
Cannot open %s
Impossibile aprire %s
Cannot write %s
Impossibile scrivere %s
Cannot create %s

Could not get %s lock
Impossibile acquisire il lock %s
The lock was created %s.

This operation may take several seconds...
Questa operazione può prendere parecchi secondi...
Forced unlock of %s lock.
Forzato lo sblocco di %s.
No unlock required.
Nessuno sblocco richiesto.
%s hours ago
%s ore fa
1 hour ago
1 ora fa
%s minutes ago
%s minuti fa
1 minute ago
1 minuto fa
%s seconds ago
%s secondi fa
1 second ago
1 secondo fa
just now
proprio ora
Edit Denied
Modifica non consentita
Editing not allowed: user, ip, or network is blocked.
Modifiche non consentite: l'utente, l'IP o la rete sono bloccati.
Contact the wiki administrator for more information.
Contattare l'amministratore della Wiki per ulteriori informazioni.
The rule %s matched for you.
La regola %s vi include.
See %s for more information.
Vedere %s per maggiori dettagli.
Editing not allowed: %s is read-only.
Modifiche non consentite: %s è in sola lettura.
Only administrators can upload files.
Solo gli amministratori possono inviare file.
Editing revision %s of
Modificando la revisione %s di
Editing %s
Modificando %s
Editing old revision %s.
Modificando la vecchia revisione %s
Saving this page will replace the latest revision with this text.
Salvare questa pagina rimpiazzerà l'ultima revisione con questo testo.
Summary:
Sunto:
This change is a minor edit.
Questa è una modifica minore.
Replace this file with text
Rimpiazza questo file con un testo
Replace this text with a file
Rimpiazza questo testo con un file
File to upload: 
File da inviare:
Files of type %s are not allowed.
I file di tipo %s non sono consentiti.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
La vostra password viene salvata in un cookie, se avete i cookie abilitati. I cookie possono andre perduti se vi connettete da un'altra macchina, da un altro account o utilizzando un altro software.
You are currently an administrator on this site.
Al momento siete amministratori su questo sito.
You are currently an editor on this site.
Al momento potete modificare le pagine di questo sito.
You are a normal user on this site.
Siete un utente normale su queto sito.
Your password does not match any of the  administrator or editor passwords.
La vostra password non coincide con nessuna di quelle degli amministratori o degli editor.
Password:

This site does not use admin or editor passwords.
Questo sito non utilizza password di amministrazione o modifica.
This operation is restricted to site editors only...
Questa operazione è consentita ai soli editor...
This operation is restricted to administrators only...
Questa operazione è consentita ai soli amministratori...
SampleUndefinedPage
PaginaEsempioIndefinita
Sample_Undefined_Page
Pagina_Esempio_Indefinita
Rule "%1" matched "%2" on this page.
La regola "%1" include "%2" su questa pagina.
Without normal pages
Senza pagine normali
Include normal pages
Includi le pagine normali
Without permanent anchors
Senza ancore permanenti
Include permanent anchors
Includi ancore permanenti
Without near pages
Senza pagine vicine
Include near pages
Includi pagine vicine
(for %s)
(per %s)
Filter:

%s pages found.
Trovate %s pagine.
Replaced: %s
Sostituito: %s
Search for: %s
Cerca: %s
View changes for these pages
Guarda le modifiche per queste pagine
Search sites on the %s as well
Cerca i siti anche su %s
and
e
or
o
Fetching results from %s:
Raccogliendo i risultati da %s:
Near pages:
Pagine vicine:
last updated
modificato l'ultima volta
by
da
Transfer Error: %s
Errore di trasferimento: %s
Browser reports no file info.
Il browser non riporta alcuna informazione sul file.
Browser reports no file type.
Il browser non riporta alcun tipo per il file.
The page contains banned text.
La pagina contiene testo bandito.
No changes to be saved.

This page was changed by somebody else %s.
Questa pagina è stata modificata da qualcun altro %s.
The changes conflict.  Please check the page again.
Le modifiche sono in conflitto. Prego ricontrollare la pagina.
Please check whether you overwrote those changes.
Prego controllate se avete sovrascritto quelle modifiche.
Anonymous
Anonimo
Cannot delete the index file %s.
Impossibile cancellare il file di indice %s.
Please check the directory permissions.
Prego verificare i permessi sulle directory.
Your changes were not saved.
Le vostre modifiche non sono state salvate.
Could not get a lock to merge!
Impossibile acquisire il blocco per la fusione!
you
voi
ancestor
antenato
other
altro
Run Maintenance
Lancia il codice di mantenimento
Maintenance not done.
Mantenimento non effettuato.
(Maintenance can only be done once every 12 hours.)
(Il mantenimento può essere effettuato al più una volta ogni 12 ore)
Remove the "maintain" file or wait.
Rimuovere il file "maintain" o attendere.
Expiring keep files and deleting pages marked for deletion
Eliminazione delle versioni obsolete e delle pagine marcate per la cancellazione
not deleted: 
non cancellati:
deleted
cancellati
Moving part of the %s log file.
Spostamento di parte del file di log %s.
Could not open %s log file
Impossibile aprire il log file %s
Error was
L'errore è
Note: This error is normal if no changes have been made.
Nota: questo errore è normale se non sono stati apportati cambiamenti.
Moving %s log entries.
Spostamento di %s elementi di log.
Getting page index file for %s.
Raccolta del file di indice di pagina per %s.
Set or Remove global edit lock
Imposta o rilascia il blocco globale di modifica
Edit lock created.
Blocco di modifica creato.
Edit lock removed.
Blocco di modifica rilasciato.
Set or Remove page edit lock
Imposta o rilascia il blocco di modifica di pagina
Lock for %s created.
Blocco per %s creato.
Lock for %s removed.
Blocco per %s rilasciato.
Displaying Wiki Version
Mostro la versione Wiki
Show dependencies
Mostra le dipendenze
Inter links:
Inter collegamenti:
Near links:
Collegamenti vicini:
Show parsed link data
Mostra i dati di collegamento recepiti
Too many connections by %s
Troppe connessioni da %s
Please do not fetch more than %1 pages in %2 seconds.
Prego non richiedere più di %1 pagine in %2 secondi.
Check whether the web server can create the directory %s and whether it can create files in it.
Verificare se il server web può creare la directory %s e se può crearvi file dentro.
anchor first defined here: %s
ancora già definita qui: %s
Click to search for references to this permanent anchor
Clicca per cercare riferimenti a questa ancora permanente
the page %s also exists
la pagina %s esiste già
Copy one of the following stylesheets to %s:

Deleting %s
Cancello %s
Deleted %s
Cancellata %s
Renaming %1 to %2.
Rinomino %1 in %2.
The page %s does not exist
La pagina %s non esiste
The page %s already exists
La pagina %s esiste già
Cannot rename %1 to %2

Renamed to %s
Rinominata a %s
Renamed from %s
Rinominata da %s
Renamed %1 to %2.
Rinominato %1 in %2.
Immediately delete %s
Cancella %s immediatamente
Rename %s to:
Rinomina %s in:
Learn more...

Complete Content
Contenuto completo
The main page is %s.
La pagina principale è %s.
Cannot highlight the language %s.
Impossibile evidenziare il linguaggio %s.
Recent Visitors
Visitatori recenti
some action

was here

and read

Illegal year value: Use 0001-9999

The match parameter is missing.
Manca il parametro di match.
Page Collection for %s
Collezione di pagine per %s
Previous
Precedente
Next
Successivo
Calendar %s
Calendiario %s
Su

Mo

Tu

We

Th

Fr

Sa

January

February

March

April

May

June

July

August

September

October

November

December

Clustermap

Pages without a Cluster

Comments on 
Commenti su
Comment on 
Commento su
Compilation for %s
Compilazione per %s
Compilation tag is missing a regular expression.
Il tag di compilazione manca di un'espressione regolare.
Despamming pages
Pagine di despamming
Cannot find revision %s.
Impossibile trovare la revisione %s
Revert to revision %1: %2
Riporta alla revisione %1: %2
Marked as %s.
Marcato come %s.
Cannot find unspammed revision.
Impossibile trovare una revisione priva di spam.
Add Comment

ordinary changes

Footnotes:
Note:
Could not find %1.html template in %2
Impossibile trovare il modello %1.html in %2
Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index
Indice
Languages:
Lingue:
Show!
Mostra!
Define
Definisci
Full Link List
Lista completa dei collegamenti
Template without parameters
Modello senza parametri
The template %s is either empty or does not exist.
Il modello %s è vuoto o non esiste.
 -- defined on %s

Local names defined on %1: %2

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

%s is not a legal name for a namespace

Clearing Cache
Ripulisco la Cache
Done.
Fatto.
Generating Link Database
Genero il database dei collegamenti
The 404 handler extension requires the link data extension (links.pl).
L'estensione di gestione 404 richiede l'estensione di dati di collegamento (links.pl).
LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List
Lista degli orfani
Trail: 
Finale:
None
Nessuno
Type
Tipo
Permalink to "%s"
Collegamento permanente a "%s"
There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Portrait
Ritratto
Publish %s

No target wiki was specified in the config file.

The target wiki was misconfigured.

You did not answer correctly.
Risposta errata.
To save this page you must answer this question:

All Referrers
Tutti i referenti
Referrers
Referenti
Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

 ... 

Search term missing.
Manca il termine da cercare.
Result pages: 

(%s results)

Tags:

Tags: %s.

No tags

Slideshow:%s

Static Copy
Copia Statica
Back to %s
Indietro a %s
Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Alternatively, use one of the following templates:
In alternativa, utilizzare uno dei seguenti modelli:
Thread: %s

ID parameter is missing.
Manca il parametro ID.
Thread %s does not exist.
Il thread %s non esiste.
Page %s does not contain a thread.
La pagina %s non contiene un thread.
Add
Aggiungi
URL parameter is missing.
Manca il parametro URL.
Add to %s thread
Aggiungi al thread %s
Below:
Sotto:
URL:

Name:
Nome:
Failed to remove %s
Impossibile rimuovere %s
Contents
Contenuto
This page is a translation of %s. 
Questa pagina è una traduzione di %s.
The translation is up to date.
La traduzione è aggiornata.
The translation is outdated.
La traduzione è obsoleta.
The page does not exist.
La pagina non esiste.
http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
alternativo
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
cerca
Wanted Pages

%s pages

%s, referenced from:

Upload of %s file

Blog

Matching pages:

New

Edit %s.

Title: 

Tags: 

END_OF_TRANSLATION
